Documentation
¶
Index ¶
- type Langfuse
- func (l *Langfuse) Agent(a *model.Agent, parentID *string) (*model.Agent, error)
- func (l *Langfuse) AgentEnd(a *model.Agent) (*model.Agent, error)
- func (l *Langfuse) Event(e *model.Event, parentID *string) (*model.Event, error)
- func (l *Langfuse) Flush(ctx context.Context)
- func (l *Langfuse) Generation(g *model.Generation, parentID *string) (*model.Generation, error)
- func (l *Langfuse) GenerationEnd(g *model.Generation) (*model.Generation, error)
- func (l *Langfuse) Guardrail(g *model.Guardrail, parentID *string) (*model.Guardrail, error)
- func (l *Langfuse) GuardrailEnd(g *model.Guardrail) (*model.Guardrail, error)
- func (l *Langfuse) Score(s *model.Score) (*model.Score, error)
- func (l *Langfuse) Shutdown(ctx context.Context) error
- func (l *Langfuse) Span(s *model.Span, parentID *string) (*model.Span, error)
- func (l *Langfuse) SpanEnd(s *model.Span) (*model.Span, error)
- func (l *Langfuse) Tool(t *model.Tool, parentID *string) (*model.Tool, error)
- func (l *Langfuse) ToolEnd(t *model.Tool) (*model.Tool, error)
- func (l *Langfuse) Trace(t *model.Trace) (*model.Trace, error)
- func (l *Langfuse) WithFlushInterval(d time.Duration) *Langfuse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Langfuse ¶
type Langfuse struct {
// contains filtered or unexported fields
}
func (*Langfuse) Flush ¶
Flush forces any pending spans to be exported and waits for completion or the context's deadline.
func (*Langfuse) Generation ¶
func (l *Langfuse) Generation(g *model.Generation, parentID *string) (*model.Generation, error)
func (*Langfuse) GenerationEnd ¶
func (l *Langfuse) GenerationEnd(g *model.Generation) (*model.Generation, error)
func (*Langfuse) GuardrailEnd ¶ added in v0.0.8
func (*Langfuse) Score ¶
Score posts to the Langfuse REST scores endpoint. OTel has no equivalent concept, so this stays on the legacy HTTP API.
Click to show internal directories.
Click to hide internal directories.